# encoding: utf-8
#
# Copyright (C) 2020 willipink.eu
# Author Moritz Münch moritzmuench@mailbox.org
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.



from datetime import datetime

from django.http import HttpResponse
from django.template import loader
from django.template.defaultfilters import register
from django.views import generic

from .models import Country, Stamp



class IndexView(generic.ListView):
    template_name = 'coinc/index.html'
    context_object_name = 'countrys'

    def get_queryset(self):
        ''' return all countries ordered by name '''
        return Country.objects.order_by('name_iso')



class DetailView(generic.DetailView):
    model = Country
    template_name = 'coinc/country.html'



@register.inclusion_tag('coinc/navigation.html')
def show_navigation(countrys):
    return {'countrys': countrys}


@register.filter(name='coins')
def coins(country, year):
    return country['years'][year]


@register.inclusion_tag('coinc/year.html')
def show_year(country, year):
    return { 'year': country['years'][year],
             'year_int': year }


@register.inclusion_tag('coinc/country.html')
def show_country(country):
    year_now = datetime.now().year
    c = {
        'name_iso': country.name_iso,
        'name': country.name,
        'comment': country.comment,
        'years': {}
    }

    irregular_stamps = {}
    stamps = Stamp.objects.filter(country=country.name_iso).values('name_short', 'years')

    if stamps:
        temp_stamps = {}
        for stamp in stamps:
            stamp_name_short = stamp['name_short']
            if stamp['years'] == "":
                temp_stamps[stamp_name_short] = {}
            else:
                for year in stamp['years'].split(","):
                    irregular_stamps[year] = {}
                    irregular_stamps[year][stamp_name_short] = {}
                temp_stamps[''] = {}
        stamps = temp_stamps
    else:
        stamps = {'': {}}

    for year in range(country.euro_member_since, year_now + 1):
        stamps_per_year = stamps
        if irregular_stamps:
            print(irregular_stamps)
            if str(year) in irregular_stamps:
                print(f"{year} in!")
                for irregular_stamp, value in irregular_stamps[str(year)].items():
                    stamps_per_year[irregular_stamp] = {}

        y = str(year)[2:4]
        c['years'][y] = {}
        for stamp in stamps_per_year:
            c['years'][y][stamp] = {'name': stamp}
    if country.name_iso == 'gr' or country.name_iso == 'de':
        print(c)

    return {'country': c}


def statistic(request):
    return HttpResponse('Statistik')
